==> haskell-hspec-golden-0.2.1.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-9i8jp3Tnng8GQxJ15F8D2x
key:                  hspec-golden-0.2.1.0-9i8jp3Tnng8GQxJ15F8D2x
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  e438e8491e4f4e51ba49ddd48eaa8928
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-9i8jp3Tnng8GQxJ15F8D2x
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1
    hspec-core-2.10.9-6HyFObTICOq7Ca9Ae8EYxc

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-golden-0.2.1.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-FsQYXdlcpDxKyGK38rDrla
key:                  hspec-golden-0.2.1.0-FsQYXdlcpDxKyGK38rDrla
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  a2f2569a4347d5095530ccee54c44f23
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-FsQYXdlcpDxKyGK38rDrla
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1
    hspec-core-2.10.9-HyKSP1TZIT2C6Hp3VlYpQt

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
